=====
Pagic
=====


.. image:: https://img.shields.io/pypi/v/pagic.svg
        :target: https://pypi.python.org/pypi/pagic

.. image:: https://img.shields.io/travis/abilian/pagic.svg
        :target: https://travis-ci.com/abilian/pagic

.. image:: https://readthedocs.org/projects/pagic/badge/?version=latest
        :target: https://pagic.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Page-oriented magical web framework.

Not ready for public consumption yet.


* Free software: Apache Software License 2.0
* Documentation: https://pagic.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cruft_ and the `abilian/cookiecutter-abilian-python`_ project template.

.. _Cruft: https://github.com/cruft/cruft
.. _`abilian/cookiecutter-abilian-python`: https://github.com/abilian/cookiecutter-abilian-python
